@@ -1,11 +1,11 @@
 """
 
-Utility to manage multiple :program:`celeryd` instances.
+Utility to manage multiple worker instances.
 
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
-from celery.bin import celeryd_multi
+from celery.bin import multi
 
 from djcelery.management.base import CeleryCommand
 
@@ -20,7 +20,7 @@ class Command(CeleryCommand):
 
     def run_from_argv(self, argv):
         argv = self.handle_default_options(argv)
-        argv.append('--cmd=%s celeryd_detach' % (argv[0], ))
-        celeryd_multi.MultiTool().execute_from_commandline(
-            ['%s %s' % (argv[0], argv[1])] + argv[2:],
+        argv.append('--cmd={0[0]} celeryd_detach'.format(argv))
+        multi.MultiTool().execute_from_commandline(
+            ['{0[0]} {0[1]}'.format(argv)] + argv[2:],
         )
