@@ -1,16 +1,16 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import sys
 import threading
 
-from celery.bin import celeryev
+from celery.bin import events
 
 from django.core.management.commands import runserver
 
 from djcelery.app import app
 from djcelery.management.base import CeleryCommand
 
-ev = celeryev.EvCommand(app=app)
+ev = events.events(app=app)
 
 
 class WebserverThread(threading.Thread):
