@@ -31,8 +31,10 @@ class TaskMeta(models.Model):
     date_done = models.DateTimeField(_('done at'), auto_now=True)
     traceback = models.TextField(_('traceback'), blank=True, null=True)
     hidden = models.BooleanField(editable=False, default=False, db_index=True)
+    # TODO compression was enabled by mistake, we need to disable it
+    # but this is a backwards incompatible change that needs planning.
     meta = PickledObjectField(
-        _('meta'), null=True, default=None, editable=False,
+        compress=True, null=True, default=None, editable=False,
     )
 
     objects = managers.TaskManager()
