@@ -1,9 +1,10 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import sys
 
 from functools import partial
 
+from billiard.einfo import ExceptionInfo
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.test.testcases import TestCase as DjangoTestCase
@@ -13,7 +14,6 @@ from anyjson import deserialize
 
 from celery import current_app
 from celery import states
-from celery.datastructures import ExceptionInfo
 from celery.task import task
 from celery.utils import gen_unique_id, get_full_cls_name
 
@@ -30,13 +30,11 @@ class MyError(Exception):
     # texts is pointless when the id the "same" KeyError does not match.
 
     def __repr__(self):
-        return '<%s: %r>' % (self.__class__.__name__, self.args)
+        return '<{0.__class__.__name__}: {0.args!r}>'.format(self)
 
 
-class MyRetryTaskError(Exception):
-
-    def __repr__(self):
-        return '<%s: %r>' % (self.__class__.__name__, self.args)
+class MyRetryTaskError(MyError):
+    pass
 
 
 task_is_successful = partial(reversestar, 'celery-is_task_successful')
@@ -59,7 +57,7 @@ def create_exception(name, base=Exception):
 def catch_exception(exception):
     try:
         raise exception
-    except exception.__class__, exc:
+    except exception.__class__ as exc:
         exc = current_app.backend.prepare_exception(exc)
         return exc, ExceptionInfo(sys.exc_info()).traceback
 
@@ -70,8 +68,8 @@ class ViewTestCase(DjangoTestCase):
         json = isinstance(json, HttpResponse) and json.content or json
         try:
             self.assertEqual(deserialize(json), py)
-        except TypeError, exc:
-            raise TypeError('%s: %s' % (exc, json))
+        except TypeError as exc:
+            raise TypeError('{0}: {1}'.format(exc, json))
 
     def assertIn(self, expected, source, *args):
         try:
